##  Create Transformations
Use transformations to model your target landscape and see the impact. Transformations are part of the SAP LeanIX Architecture and Road Map Planning product. SAP LeanIX Architecture and Road Map Planning helps you to execute your defined TIME strategies.
  1. Go to the Initiative fact sheet and navigate to the Transformation tab.
  2. Click New Transformation and select a template, for example:
     * Decommission Application if you want to work on sunsetting the applications of the Eliminate quadrant
     * Change Application Technology if you want to start migrating applications
![Create transformation dialog with selection of transformation types](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio190e4b14edaa45d4bd6bb5d0b8b92ce7_HiRes.png)
  3. Each template has predefined relations and fields that will guide you through the transformation.
![Create transformation dialog with fields for name, description, application, and related options](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio5f22b513b9ce4e4a919d075e9dca7f9b_HiRes.png)
  4. Add a custom impact if needed. In the transformations tab, select the affected initiative and click Add for custom impact.
Custom impacts allow you to factor in future budget planning. For example, license cost can go down once the transformation is done. With a custom impact you already plan the lower license costs and once the transformation is executed, the license cost field is automatically populated with the new value.
![Form to set licensing costs for an application fact sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiobaff1ab3af7f4b7a98a52179440c579c_HiRes.png)
  5. Add all planned transformations.
